import { Color } from './Color';
import { FontVariant } from './FontVariant';
import { ITextProperties } from './ITextProperties';
import { LineMode } from './LineMode';
import { LineStyle } from './LineStyle';
import { LineType } from './LineType';
import { LineWidth } from './LineWidth';
import { TextLine } from './TextLine';
import { TextTransformation } from './TextTransformation';
import { Typeface } from './Typeface';
/**
 * This class represents the style of some text.
 *
 * @extends ITextProperties
 * @since 0.4.0
 * @private
 */
export declare class TextProperties implements ITextProperties {
    private backgroundColor;
    private color;
    private fontName;
    private fontSize;
    private fontVariant;
    private transformation;
    private typeface;
    private underline;
    /**
     * Constructor.
     *
     * @since 0.4.0
     */
    constructor();
    /** @inheritDoc */
    setBackgroundColor(color: Color | undefined): void;
    /** @inheritDoc */
    getBackgroundColor(): Color | undefined;
    /** @inheritDoc */
    setColor(color: Color | undefined): void;
    /** @inheritDoc */
    getColor(): Color | undefined;
    /** @inheritDoc */
    setFontName(name: string): void;
    /** @inheritDoc */
    getFontName(): string | undefined;
    /** @inheritDoc */
    setFontSize(size: number): void;
    /** @inheritDoc */
    getFontSize(): number;
    /** @inheritDoc */
    setFontVariant(fontVariant: FontVariant): void;
    /** @inheritDoc */
    getFontVariant(): FontVariant;
    /** @inheritDoc */
    setTextTransformation(transformation: TextTransformation): void;
    /** @inheritDoc */
    getTextTransformation(): TextTransformation;
    /** @inheritDoc */
    setTypeface(typeface: Typeface): void;
    /** @inheritDoc */
    getTypeface(): Typeface;
    /** @inheritDoc */
    setUnderline(color?: 'font-color' | Color, width?: LineWidth | number, style?: LineStyle, type?: LineType, mode?: LineMode): void;
    /** @inheritDoc */
    getUnderline(): TextLine | undefined;
    /** @inheritDoc */
    removeUnderline(): void;
}
