"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FontFaceDeclarationsWriter = void 0;
const OdfElementName_1 = require("../OdfElementName");
/**
 * Transforms a {@link FontFaceDeclarations} object into ODF conform XML
 *
 * @since 0.8.0
 */
class FontFaceDeclarationsWriter {
    /**
     * Transforms the given {@link FontFaceDeclarations} into Open Document Format.
     *
     * @param {Document} document The XML document
     * @param {Element} parent The parent node in the DOM
     * @param {FontFaceDeclarations} fontFaceDeclarations The font face declarations to serialize
     * @since 0.7.0
     */
    write(fontFaceDeclarations, document, root) {
        const fonts = fontFaceDeclarations.getAll();
        if (fonts.length === 0) {
            return;
        }
        const fontFaceDeclsElement = document.createElement(OdfElementName_1.OdfElementName.OfficeFontFaceDeclarations);
        root.appendChild(fontFaceDeclsElement);
        fonts.forEach((font) => {
            this.visitFontFace(font, document, fontFaceDeclsElement);
        });
    }
    visitFontFace(font, document, parent) {
        const fontFaceElement = document.createElement(OdfElementName_1.OdfElementName.StyleFontFace);
        parent.appendChild(fontFaceElement);
        fontFaceElement.setAttribute('style:name', font.getName());
        const fontFamily = font.getFontFamily();
        if (fontFamily !== undefined) {
            const encodedFontFamily = fontFamily.includes(' ') === true ? `'${fontFamily}'` : fontFamily;
            fontFaceElement.setAttribute('svg:font-family', encodedFontFamily);
        }
        const fontPitch = font.getFontPitch();
        if (fontPitch !== undefined) {
            fontFaceElement.setAttribute('style:font-pitch', fontPitch);
        }
        return fontFaceElement;
    }
}
exports.FontFaceDeclarationsWriter = FontFaceDeclarationsWriter;
